<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@sqmail.org
    Home Site ...... http://www.sqmail.org/
    Program ........ Address Add
    Purpose ........ Allows you to add the From address to the address book

*******************************************************************************/

header("Location: ../../../index.php");

?>